Notebook[{

Cell[CellGroupData[{
Cell["On the streaming in a microfluidic Kundt\[CloseCurlyQuote]s tube", \
"Title",ExpressionUUID->"67bc2cc6-1ead-4daf-b5c5-59b7c0a53eee"],

Cell["\<\
Alen Pavlic* and J\[UDoubleDot]rg Dual
Institute for Mechanical Systems, ETH Zurich, Tannenstrasse 3, 8092 Zurich, \
Switzerland\
\>", "Subtitle",ExpressionUUID->"b057263a-c7dc-4052-ad20-79bf53037353"],

Cell["\<\
This is a supplementary Mathematica code that implements the solutions \
presented in the corresponding manuscript. The change in the input parameters \
(radius/frequency/material parameters) might require adaption of the input \
values for searching the wavenumber and/or adaption of \
\[OpenCurlyDoubleQuote]iMax\[CloseCurlyDoubleQuote] number at which the \
infinite sums are truncated.\
\>", "Text",ExpressionUUID->"98e14572-9503-404d-8bbb-1886ef865c29"],

Cell[" * Correspondence address: apavlic@ethz.ch", \
"Text",ExpressionUUID->"5b93ef67-09fd-4dfd-bb16-37b35bac4df5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Bessel", " ", "functions"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"J0", "[", "x_", "]"}], ":=", 
     RowBox[{"BesselJ", "[", 
      RowBox[{"0", ",", "x"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"J1", "[", "x_", "]"}], ":=", 
     RowBox[{"BesselJ", "[", 
      RowBox[{"1", ",", "x"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"J2", "[", "x_", "]"}], ":=", 
     RowBox[{"BesselJ", "[", 
      RowBox[{"2", ",", "x"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y0", "[", "x_", "]"}], ":=", 
     RowBox[{"BesselY", "[", 
      RowBox[{"0", ",", "x"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y1", "[", "x_", "]"}], ":=", 
     RowBox[{"BesselY", "[", 
      RowBox[{"1", ",", "x"}], "]"}]}], ";"}]}]}]], "Input",
 CellLabel->"In[1]:=",ExpressionUUID->"fccbbb54-6a8a-4919-9b3d-21e916dea637"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"q", "[", 
     RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
    RowBox[{"Sqrt", "[", 
     RowBox[{
      RowBox[{"x", "^", "2"}], "-", 
      RowBox[{"y", "^", "2"}]}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"helper", " ", "function"}], "*)"}]}]], "Input",
 CellLabel->"In[6]:=",ExpressionUUID->"f57d4a28-ebdb-4ff9-9a77-57c2f36fb585"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"qf", "[", 
     RowBox[{"kr_", ",", "ki_"}], "]"}], ":=", 
    RowBox[{"q", "[", 
     RowBox[{"kf", ",", 
      RowBox[{"(", 
       RowBox[{"kr", "+", 
        RowBox[{"\[ImaginaryI]", "*", "ki"}]}], ")"}]}], "]"}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"qv", "[", 
    RowBox[{"kr_", ",", "ki_"}], "]"}], ":=", 
   RowBox[{"q", "[", 
    RowBox[{"kv", ",", 
     RowBox[{"(", 
      RowBox[{"kr", "+", 
       RowBox[{"\[ImaginaryI]", "*", "ki"}]}], ")"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellLabel->"In[7]:=",ExpressionUUID->"b4b84a83-8964-4822-b625-f63da4726a0c"],

Cell[CellGroupData[{

Cell["Sample parameters", \
"Section",ExpressionUUID->"6ab8eee5-be29-4430-8bfe-bd50f422e589"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"a", "=", 
    RowBox[{"40", "*", 
     RowBox[{"10", "^", 
      RowBox[{"(", 
       RowBox[{"-", "6"}], ")"}]}]}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"tube", " ", "radius", " ", 
    RowBox[{"in", " ", "[", "m", "]"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Freq", "=", "100000"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"frequency", " ", 
    RowBox[{"in", " ", "[", "Hz", "]"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pA", " ", "=", " ", "100000"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"pressure", " ", "amplitude", " ", 
    RowBox[{"in", " ", "[", "Pa", "]"}]}], "*)"}]}]}], "Input",
 CellLabel->"In[9]:=",ExpressionUUID->"3a3db68d-dac9-4b69-9c13-a6a26f3bf568"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"iMax", "=", "100"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "limit", " ", "for", " ", "truncation", " ", "of", " ", "infinite", " ", 
     "sums", " ", "for", " ", "functions", " ", "S_R", " ", "and", " ", "S_I",
      " ", "in", " ", "equations", " ", 
     RowBox[{"(", "4.26", ")"}], " ", "and", " ", 
     RowBox[{"(", "4.27", ")"}]}], ",", " ", 
    RowBox[{
    "and", " ", "constants", " ", "C_", "1", " ", "and", " ", "C_", "3", " ", 
     "in", " ", "equations", " ", 
     RowBox[{"(", "4.56", ")"}], " ", "and", " ", 
     RowBox[{"(", "4.57", ")"}]}]}], 
   "*)"}]}]], "Input",ExpressionUUID->"54696de7-5d2e-48ff-b4e5-f0c986c0d3dd"],

Cell[CellGroupData[{

Cell["Material parameters", \
"Subsection",ExpressionUUID->"6cf448a8-192f-46fd-b7f0-835ed195dc71"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", "oil", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"rhof", " ", "=", " ", "922.6"}], ";"}], " ", 
   RowBox[{"(*", 
    RowBox[{"density", " ", 
     RowBox[{"in", " ", "[", 
      RowBox[{"kg", "/", 
       RowBox[{"m", "^", "3"}]}], "]"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cf", " ", "=", " ", "1445"}], ";"}], " ", 
   RowBox[{"(*", 
    RowBox[{"speed", " ", "of", " ", "sound", " ", 
     RowBox[{"in", " ", "[", 
      RowBox[{"m", "/", "s"}], "]"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"etaf", " ", "=", " ", "0.04153"}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"dynamic", " ", "viscosity", " ", 
     RowBox[{"in", " ", "[", 
      RowBox[{"Pa", "*", "s"}], "]"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ksif", " ", "=", " ", "0.083"}], ";"}], " ", 
   RowBox[{"(*", 
    RowBox[{"bulk", " ", "viscosity", " ", 
     RowBox[{"in", " ", "[", 
      RowBox[{"Pa", "*", "s"}], "]"}]}], "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", "\[IndentingNewLine]", 
    RowBox[{"(*", "water", "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rhof", " ", "=", " ", "996.6"}], ";", " ", 
     RowBox[{"(*", 
      RowBox[{"density", " ", 
       RowBox[{"in", " ", "[", 
        RowBox[{"kg", "/", 
         RowBox[{"m", "^", "3"}]}], "]"}]}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"cf", " ", "=", " ", "1502"}], ";", " ", 
     RowBox[{"(*", 
      RowBox[{"speed", " ", "of", " ", "sound", " ", 
       RowBox[{"in", " ", "[", 
        RowBox[{"m", "/", "s"}], "]"}]}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"etaf", " ", "=", " ", "0.0008538"}], ";", " ", 
     RowBox[{"(*", 
      RowBox[{"dynamic", " ", "viscosity", " ", 
       RowBox[{"in", " ", "[", 
        RowBox[{"Pa", "*", "s"}], "]"}]}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"ksif", " ", "=", " ", "0.0024"}], ";"}], " ", 
    RowBox[{"(*", 
     RowBox[{"bulk", " ", "viscosity", " ", 
      RowBox[{"in", " ", "[", 
       RowBox[{"Pa", "*", "s"}], "]"}]}], "*)"}], "\[IndentingNewLine]", 
    "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", "\[IndentingNewLine]", 
    RowBox[{"(*", "glycerol", "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rhof", " ", "=", " ", "1261.34"}], ";", " ", 
     RowBox[{"(*", 
      RowBox[{"density", " ", 
       RowBox[{"in", " ", "[", 
        RowBox[{"kg", "/", 
         RowBox[{"m", "^", "3"}]}], "]"}]}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"cf", " ", "=", " ", "1920"}], ";", " ", 
     RowBox[{"(*", 
      RowBox[{"speed", " ", "of", " ", "sound", " ", 
       RowBox[{"in", " ", "[", 
        RowBox[{"m", "/", "s"}], "]"}]}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"etaf", " ", "=", " ", "1.41"}], ";", " ", 
     RowBox[{"(*", 
      RowBox[{"dynamic", " ", "viscosity", " ", 
       RowBox[{"in", " ", "[", 
        RowBox[{"Pa", "*", "s"}], "]"}]}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"ksif", " ", "=", " ", "2.0"}], ";"}], " ", 
    RowBox[{"(*", 
     RowBox[{"bulk", " ", "viscosity", " ", 
      RowBox[{"in", " ", "[", 
       RowBox[{"Pa", "*", "s"}], "]"}]}], "*)"}], "\[IndentingNewLine]", 
    "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", "\[IndentingNewLine]", 
    RowBox[{"(*", "air", "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rhof", " ", "=", " ", "1.161"}], ";", " ", 
     RowBox[{"(*", 
      RowBox[{"density", " ", 
       RowBox[{"in", " ", "[", 
        RowBox[{"kg", "/", 
         RowBox[{"m", "^", "3"}]}], "]"}]}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"cf", " ", "=", " ", "347.4"}], ";", " ", 
     RowBox[{"(*", 
      RowBox[{"speed", " ", "of", " ", "sound", " ", 
       RowBox[{"in", " ", "[", 
        RowBox[{"m", "/", "s"}], "]"}]}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"etaf", " ", "=", " ", "0.00001854"}], ";", " ", 
     RowBox[{"(*", 
      RowBox[{"dynamic", " ", "viscosity", " ", 
       RowBox[{"in", " ", "[", 
        RowBox[{"Pa", "*", "s"}], "]"}]}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"ksif", " ", "=", " ", "0.000011"}], ";"}], " ", 
    RowBox[{"(*", 
     RowBox[{"bulk", " ", "viscosity", " ", 
      RowBox[{"in", " ", "[", 
       RowBox[{"Pa", "*", "s"}], "]"}]}], "*)"}], "\[IndentingNewLine]", 
    "*)"}]}]}]], "Input",
 CellLabel->
  "In[12]:=",ExpressionUUID->"e24cb282-412b-42f4-bd88-22e2f8467d51"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dispersion relation", \
"Section",ExpressionUUID->"cb744e94-c525-4d2c-9543-17eb36ee31e7"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"omega", " ", "=", " ", 
    RowBox[{"2", "*", "Pi", "*", "Freq"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"angular", " ", "frequency"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"kf", "=", 
    RowBox[{
     RowBox[{"omega", "/", "cf"}], "*", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"\[ImaginaryI]", "*", 
         RowBox[{"omega", "/", 
          RowBox[{"(", 
           RowBox[{"rhof", "*", 
            RowBox[{"cf", "^", "2"}]}], ")"}]}], "*", 
         RowBox[{"(", 
          RowBox[{"ksif", "+", 
           RowBox[{
            RowBox[{"4", "/", "3"}], "*", "etaf"}]}], ")"}]}]}], ")"}], "^", 
      RowBox[{"(", 
       RowBox[{"-", "0.5"}], ")"}]}]}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
   "wavenumber", " ", "in", " ", "an", " ", "unbounded", " ", "viscous", " ", 
    "fluid"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"deltaf", " ", "=", " ", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"2", "*", 
      RowBox[{"etaf", "/", 
       RowBox[{"(", 
        RowBox[{"rhof", "*", "omega"}], ")"}]}]}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"viscous", " ", "boundary", " ", "layer", " ", "thickness"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"kv", " ", "=", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "/", 
     RowBox[{"(", "deltaf", ")"}]}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"viscous", " ", "wavenumber"}], 
   "*)"}]}], "\[IndentingNewLine]"}], "Input",
 CellLabel->"In[16]:=",ExpressionUUID->"da9d4743-2aa2-4508-a75a-b2c59ae67170"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Disp", "[", 
    RowBox[{"kr_", ",", " ", "ki_", ",", "tubeRadius_"}], "]"}], ":=", 
   RowBox[{"Det", "[", 
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{
         RowBox[{"-", 
          RowBox[{"qf", "[", 
           RowBox[{"kr", ",", "ki"}], "]"}]}], "*", 
         RowBox[{"J1", "[", 
          RowBox[{
           RowBox[{"qf", "[", 
            RowBox[{"kr", ",", "ki"}], "]"}], "*", "tubeRadius"}], "]"}]}], 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], "*", 
         RowBox[{"(", 
          RowBox[{"kr", "+", 
           RowBox[{"\[ImaginaryI]", "*", "ki"}]}], ")"}], "*", 
         RowBox[{"J1", "[", 
          RowBox[{
           RowBox[{"qv", "[", 
            RowBox[{"kr", ",", "ki"}], "]"}], "*", "tubeRadius"}], "]"}]}]},
       {
        RowBox[{"\[ImaginaryI]", "*", 
         RowBox[{"(", 
          RowBox[{"kr", "+", 
           RowBox[{"\[ImaginaryI]", "*", "ki"}]}], ")"}], "*", 
         RowBox[{"J0", "[", 
          RowBox[{
           RowBox[{"qf", "[", 
            RowBox[{"kr", ",", "ki"}], "]"}], "*", "tubeRadius"}], "]"}]}], 
        RowBox[{
         RowBox[{"qv", "[", 
          RowBox[{"kr", ",", "ki"}], "]"}], "*", 
         RowBox[{"J0", "[", 
          RowBox[{
           RowBox[{"qv", "[", 
            RowBox[{"kr", ",", "ki"}], "]"}], "*", "tubeRadius"}], "]"}]}]}
      },
      GridBoxDividers->{
       "Columns" -> {{True}}, "ColumnsIndexed" -> {}, "Rows" -> {{True}}, 
        "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[20]:=",ExpressionUUID->"dc7ec9e8-0fc3-438d-806a-bc04e6eb62c1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "computing", " ", "actual", " ", "wavenumber", " ", "inside", " ", "a", 
    " ", "tube"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"kR", ",", "kI"}], "}"}], "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"kreal", ",", "kimag"}], "}"}], "/.", 
      RowBox[{"FindRoot", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Re", "[", 
            RowBox[{"Disp", "[", 
             RowBox[{"kreal", ",", "kimag", ",", "a"}], "]"}], "]"}], 
           "\[Equal]", "0"}], ",", " ", 
          RowBox[{
           RowBox[{"Im", "[", 
            RowBox[{"Disp", "[", 
             RowBox[{"kreal", ",", "kimag", ",", "a"}], "]"}], "]"}], 
           "\[Equal]", "0"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"kreal", ",", 
            RowBox[{"Re", "[", "kf", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"kimag", ",", 
            RowBox[{"Im", "[", "kf", "]"}]}], "}"}]}], "}"}]}], "]"}]}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"k", " ", "=", " ", 
     RowBox[{"kR", "+", 
      RowBox[{"\[ImaginaryI]", "*", "kI"}]}]}], ";"}], " ", 
   RowBox[{"(*", 
    RowBox[{"actual", " ", "wavenumber"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Lambda]R", "=", 
     RowBox[{"2", "*", 
      RowBox[{"Pi", "/", "kR"}]}]}], ";"}], " ", 
   RowBox[{"(*", 
    RowBox[{"actual", " ", "wavelength"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Lambda]", "=", 
     RowBox[{"2", "*", 
      RowBox[{"Pi", "/", 
       RowBox[{"Re", "[", "kf", "]"}]}]}]}], ";"}], " ", 
   RowBox[{"(*", 
    RowBox[{"ideal", " ", "wavelength"}], "*)"}], 
   "\[IndentingNewLine]"}]}]], \
"Input",ExpressionUUID->"5693401e-d3b3-4bf1-8386-98d8b340b606"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Unknown constants at the first order", \
"Section",ExpressionUUID->"4ef45ecd-c8d7-4094-bc26-07697bf57e70"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"qf", "=", 
   RowBox[{"qf", "[", 
    RowBox[{"kR", ",", "kI"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"qv", "=", 
   RowBox[{"qv", "[", 
    RowBox[{"kR", ",", "kI"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"A1", " ", "=", " ", 
   RowBox[{
    RowBox[{"-", "\[ImaginaryI]"}], "*", "pA", "*", 
    RowBox[{"omega", "/", 
     RowBox[{"(", 
      RowBox[{"2", "*", "rhof", "*", 
       RowBox[{"cf", "^", "2"}], "*", 
       RowBox[{"kf", "^", "2"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"B1", "=", 
   RowBox[{"\[ImaginaryI]", "*", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"qf", "*", 
       RowBox[{"J1", "[", 
        RowBox[{"qf", "*", "a"}], "]"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"k", "*", 
       RowBox[{"J1", "[", 
        RowBox[{"qv", "*", "a"}], "]"}]}], ")"}]}], "*", "A1"}]}], 
  ";"}]}], "Input",
 CellLabel->
  "In[25]:=",ExpressionUUID->"2400931b-8f0f-457f-bf8c-dfbc47e3b90a"]
}, Open  ]],

Cell[CellGroupData[{

Cell["First - order (acoustic) fields", \
"Section",ExpressionUUID->"0171f670-56e8-496a-a3c5-ed69189f26e4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"helper", " ", "functions"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "r1_", "]"}], "=", 
     RowBox[{"A1", "*", 
      RowBox[{"J0", "[", 
       RowBox[{"qf", "*", "r1"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"G", "[", "r2_", "]"}], "=", 
     RowBox[{"B1", "*", 
      RowBox[{"J1", "[", 
       RowBox[{"qv", "*", "r2"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"F1", "[", "r3_", "]"}], "=", 
     RowBox[{"F", "[", "r3", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"F2", "[", "r4_", "]"}], "=", 
     RowBox[{"A1", "*", 
      RowBox[{"J1", "[", 
       RowBox[{"qf", "*", "r4"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"G1", "[", "r5_", "]"}], "=", 
     RowBox[{"G", "[", "r5", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"G2", "[", "r6_", "]"}], "=", 
     RowBox[{"B1", "*", 
      RowBox[{"J0", "[", 
       RowBox[{"qv", "*", "r6"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"velocity", " ", "field"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"v1ForwardR", "[", 
      RowBox[{"r_", ",", "z_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "qf"}], "*", 
         RowBox[{"F2", "[", "r", "]"}]}], "-", 
        RowBox[{"\[ImaginaryI]", "*", "k", "*", 
         RowBox[{"G", "[", "r", "]"}]}]}], ")"}], "*", 
      RowBox[{"Exp", "[", 
       RowBox[{"\[ImaginaryI]", "*", "k", "*", "z"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"v1ForwardZ", "[", 
      RowBox[{"r_", ",", "z_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[ImaginaryI]", "*", "k", "*", 
         RowBox[{"F", "[", "r", "]"}]}], "+", 
        RowBox[{
         RowBox[{"1", "/", "r"}], "*", 
         RowBox[{"G", "[", "r", "]"}]}], "+", 
        RowBox[{
         RowBox[{"G", "'"}], "[", "r", "]"}]}], ")"}], "*", 
      RowBox[{"Exp", "[", 
       RowBox[{"\[ImaginaryI]", "*", "k", "*", "z"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"v1BackwardR", "[", 
      RowBox[{"r_", ",", "z_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "qf"}], "*", 
         RowBox[{"F2", "[", "r", "]"}]}], "-", 
        RowBox[{"\[ImaginaryI]", "*", "k", "*", 
         RowBox[{"G", "[", "r", "]"}]}]}], ")"}], "*", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], "*", "k", "*", "z"}], "]"}]}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"v1BackwardZ", "[", 
      RowBox[{"r_", ",", "z_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], "*", "k", "*", 
         RowBox[{"F", "[", "r", "]"}]}], "-", 
        RowBox[{
         RowBox[{"1", "/", "r"}], "*", 
         RowBox[{"G", "[", "r", "]"}]}], "-", 
        RowBox[{
         RowBox[{"G", "'"}], "[", "r", "]"}]}], ")"}], "*", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], "*", "k", "*", "z"}], "]"}]}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"v1r", "[", 
      RowBox[{"r_", ",", "z_"}], "]"}], "=", 
     RowBox[{
      RowBox[{"v1ForwardR", "[", 
       RowBox[{"r", ",", "z"}], "]"}], "+", 
      RowBox[{"v1BackwardR", "[", 
       RowBox[{"r", ",", "z"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"v1z", "[", 
      RowBox[{"r_", ",", "z_"}], "]"}], "=", 
     RowBox[{
      RowBox[{"v1ForwardZ", "[", 
       RowBox[{"r", ",", "z"}], "]"}], "+", 
      RowBox[{"v1BackwardZ", "[", 
       RowBox[{"r", ",", "z"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"pressure", " ", "field"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"pressure", "[", 
      RowBox[{"r_", ",", "z_"}], "]"}], ":=", 
     RowBox[{"pA", "*", 
      RowBox[{"J0", "[", 
       RowBox[{"qf", "*", "r"}], "]"}], "*", 
      RowBox[{"Cos", "[", 
       RowBox[{"k", "*", "z"}], "]"}]}]}], ";"}]}]}]], "Input",
 CellLabel->"In[29]:=",ExpressionUUID->"83f5c35c-6d28-4b73-bfab-f0fb270c3caf"],

Cell[CellGroupData[{

Cell["Pressure analysis", \
"Subsection",ExpressionUUID->"01e39feb-8d53-4115-954f-f5cbd7d54049"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"plotting", " ", "pressure", " ", "field"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"Re", "[", 
      RowBox[{"pressure", "[", 
       RowBox[{"rTest", ",", "0"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"rTest", ",", "0", ",", "a"}], "}"}], ",", 
     RowBox[{
     "PlotLabel", "\[Rule]", "\"\<Pressure along radial direction\>\""}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"r", ",", 
        SubscriptBox["p", "1"]}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"Re", "[", 
      RowBox[{"pressure", "[", 
       RowBox[{"0", ",", "zTest"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"zTest", ",", 
       RowBox[{
        RowBox[{"-", "\[Lambda]"}], "*", "5"}], ",", 
       RowBox[{"\[Lambda]", "*", "5"}]}], "}"}], ",", 
     RowBox[{
     "PlotLabel", "\[Rule]", "\"\<Pressure along axial direction\>\""}], ",", 
     
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"z", ",", 
        SubscriptBox["p", "1"]}], "}"}]}]}], "]"}]}]}]], "Input",
 CellLabel->"In[42]:=",ExpressionUUID->"48515237-533b-4ca1-bfa5-a14c2a0724ab"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwl1Qk0VWsbB3CObYxOdEx9p2OoKyEakPHZfDhFXdE1HEVlSnVdMpQylCGJ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       "]]},
     Annotation[#, "Charting`Private`Tag$1142#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["r", TraditionalForm], 
    FormBox[
     SubscriptBox["p", "1"], TraditionalForm]},
  AxesOrigin->{0, 100000.},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox["\"Pressure along radial direction\"", TraditionalForm],
  PlotRange->NCache[{{0, 
      Rational[1, 25000]}, {100000., 100001.9949999932}}, {{0, 0.00004}, {
     100000., 100001.9949999932}}],
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellLabel->"Out[42]=",ExpressionUUID->"55a46723-9041-4109-9d82-a7dcd3164478"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[{{-0.07224999710620722, -6.827813440914654*^6}, \
{-0.07222518762260288, -7.135496929301724*^6}}], 
      LineBox[{{-0.06727313531022167, -7.135496929301724*^6}, \
{-0.06710747146621693, -5.709473806171773*^6}, {-0.06633874245182285, 
       765312.1019494474}, {-0.06629388078652236, 
       1.1224556271316218`*^6}, {-0.06624901912122187, 
       1.4762441875495645`*^6}, {-0.0661592957906209, 
       2.1731429889684045`*^6}, {-0.06597984912941894, 
       3.520103655999702*^6}, {-0.06593498746411845, 
       3.8462635806720974`*^6}, {-0.06589012579881796, 
       4.16792226465724*^6}, {-0.06580040246821699, 
       4.797224067523376*^6}, {-0.06562095580701503, 
       5.996372872513748*^6}, {-0.06557609414171454, 
       6.283107264160994*^6}, {-0.0655654379683621, 6.349925324086671*^6}}], 
      LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAA035O3YVwr78F1r1UGTlYQeIjUbYd
aq+/t+/0f/ZbV0F7QFY94Q2vvy6Zu+6ePURBWHBzYKAHr7+suVCxFW9CQTag
kINfAa+/MhJBiamhQEHy/8rJ3fSuv0UCSu9cFjpBar8/Vtrbrr+lSbz5rton
QVo+KW/Tqa6/TFxkYNBtLsE4bkaSkqOuvyTF1rlydjLBFp5jtVGdrr+D/luW
YKw1wdL9nfvPkK6/TXkMS9X5O8FKvRKIzHeuv+NUUZhXCETBKO0vq4txrr9O
7EWWaHxFwQYdTc5Ka66/ll4CSjnqRsHCfIcUyV6uvxpzgFl4sknBOjz8oMVF
rr/nAQo/S/FOwRhsGcSEP66/SmFsnpcXUMH2mzbnQzmuvxQGwPnYslDBsvtw
LcIsrr8VewMsDt5RwZArjlCBJq6/xpeI6OVtUsFuW6tzQCCuv7Af6M3U+VLB
Krvlub4Trr9I60JixwVUwQjrAt19Da6/PjIGcLSFVMHmGiAAPQeuvxzMoGSL
AVXBonpaRrv6rb/euRdQ0exVwYCqd2l69K2/WWPEJS9cVsFe2pSMOe6tv4BH
hZ9Ux1bBGjrP0rfhrb/vUFbH25BXwfhp7PV2262/cpoMzjHvV8HWmQkZNtWt
v9W89ig4SVjBkvlDX7TIrb8VgAsARvBYwXApYYJzwq2/DBTzO0c9WcFOWX6l
Mrytv/QknEnshVnBCrm467Cvrb8JDFSlHApawejo1Q5wqa2/E/Z/+6ZFWsHG
GPMxL6OtvwBrBjHTfFrBpEgQVe6crb8M/3Fmoq9awYJ4LXitlq2/HLWiXhbe
WsFgqEqbbJCtv0YxM30xCFvBPthnviuKrb86n8nE9i1bwc7aYws/iK2/8K15
O0I4W8FPC1Ot
       "]], LineBox[CompressedData["
1:eJwUV3c4l98blk3GJ9mEfO0oO0nOe4hsSsmIEFJGVvZe2XvvvUvLKNV5X6Od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       "]], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAA496sN0SIrT/wrXk7QjhbwWjq63Ow
ia0/rTrIhbEwW8Gu6yt4jo+tP5fuonKxDVvB9exrfGyVrT8jeDvD4OZawTzu
q4BKm60/83ng5Dy8WsGC7+uEKKGtP44t3b/DjVrByfAriQanrT+WOra4c1ta
wRDya43krK0/OcdYsUslWsGd9OuVoLitP6JPcaNxrVnB5PUrmn6+rT8Pla3d
v2tZwSr3a55cxK0/3IA5mzYmWcG4+eumGNCtPz8Nqbajj1jB//orq/bVrT+t
zNhonj5YwUb8a6/U260/zt9vSMrpV8HT/uu3kOetP9SR6e/DNFfBGgAsvG7t
rT8sUYw3mtRWwWABbMBM860/qeUUrbJwVsHuA+zICP+tP1a6dPDAnVXBNQUs
zeYErj+1aVx5wy5VwXwGbNHECq4/36rBpiG8VMEJCezZgBauPytVVUAQzFPB
JA7s6vgtrj/csMx+r8FRwWsPLO/WM64/2oOOfoQ2UcGyEGzztDmuP5Te3JsB
qFDBPxPs+3BFrj/huoH4SAJPwVoY7AzpXK4/DLM+afgaSsGPIuwu2YuuPzJh
Fa51bj7B1iMsM7eRrj+91iTauIY7wRwlbDeVl64/4u/8xo2VOMGqJ+w/UaOu
PxP4ek8tmDLBxCzsUMm6rj+AaTgxqekYwfo27HK56a4/gO7E2Fy+M0Enn/bv
ee+uPzY92VgTAzdBVAcBbTr1rj/NsVtVUks6Qa7XFWe7AK8/70WC2G5yQEFj
eD9bvRevP6RYgYmLGEdBzLmSQ8FFrz9HIrAFkjRSQfkhncCBS68/5A5ATcEH
U0Emiqc9QlGvP8uSdCgr2lNBgFq8N8Ncrz+aF0yTPnxVQdugxLlgcK8/Bda9
VBk5WEFFRlLq
       "]], 
      LineBox[{{0.06556551126235885, 6.349925324086671*^6}, {
       0.06556604194849151, 6.346614306971333*^6}, {0.06566126464454541, 
       5.734187986272095*^6}, {0.0658517100366532, 4.439688615359455*^6}, {
       0.06623260082086879, 1.6048532995996983`*^6}, {0.0662770282707966, 
       1.2557599081504259`*^6}, {0.0663214557207244, 903319.0634348498}, {
       0.06641031062058002, 189003.5747553492}, {
       0.06658802042029124, -1.2729497741990534`*^6}, {
       0.0669434400197137, -4.292713124428122*^6}, {
       0.0669878674696415, -4.6757413702380145`*^6}, {
       0.0670322949195693, -5.059394077960805*^6}, {
       0.06712114981942492, -5.8278178387748245`*^6}, {
       0.06727244901600311, -7.135496929301724*^6}}], 
      LineBox[{{0.07222516654367428, -7.135496929301724*^6}, {
       0.07224999710620722, -6.827813440914654*^6}}]},
     Annotation[#, "Charting`Private`Tag$1262#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["z", TraditionalForm], 
    FormBox[
     SubscriptBox["p", "1"], TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox["\"Pressure along axial direction\"", TraditionalForm],
  PlotRange->{{-0.07225000005518681, 
   0.07225000005518681}, {-7.135496929301724*^6, 6.349925324086671*^6}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellLabel->
  "Out[43]=",ExpressionUUID->"243fb0e3-4a79-4fee-a59b-35719e438a42"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Second - order (streaming) source terms", \
"Section",ExpressionUUID->"3ae655a4-49bf-4fc1-a345-ec00b95b8df7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"helper", " ", "functions"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Par1", "[", "r7_", "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"qf", "^", "2"}]}], "*", 
       RowBox[{"F1", "[", "r7", "]"}]}], "+", 
      RowBox[{
       RowBox[{"1", "/", "r7"}], "*", "qf", "*", 
       RowBox[{"F2", "[", "r7", "]"}]}], "+", 
      RowBox[{
       RowBox[{"1", "/", "r7"}], "*", "\[ImaginaryI]", "*", "k", "*", 
       RowBox[{"G1", "[", "r7", "]"}]}], "-", 
      RowBox[{"\[ImaginaryI]", "*", "k", "*", "qv", "*", 
       RowBox[{"G2", "[", "r7", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Par2", "[", "r8_", "]"}], "=", 
     RowBox[{
      RowBox[{"k", "*", "qf", "*", 
       RowBox[{"F2", "[", "r8", "]"}]}], "+", 
      RowBox[{"\[ImaginaryI]", "*", 
       RowBox[{"k", "^", "2"}], "*", 
       RowBox[{"G1", "[", "r8", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Par3", "[", "r9_", "]"}], "=", 
     RowBox[{
      RowBox[{"k", "*", "qf", "*", 
       RowBox[{"F2", "[", "r9", "]"}]}], "-", 
      RowBox[{"\[ImaginaryI]", "*", 
       RowBox[{"qv", "^", "2"}], "*", 
       RowBox[{"G1", "[", "r9", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Par4", "[", "r10_", "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"k", "^", "2"}]}], "*", 
       RowBox[{"F1", "[", "r10", "]"}]}], "+", 
      RowBox[{"\[ImaginaryI]", "*", "k", "*", "qv", "*", 
       RowBox[{"G2", "[", "r10", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Par5", "[", "r11_", "]"}], "=", 
     RowBox[{
      RowBox[{"k", "*", 
       RowBox[{"qf", "^", "2"}], "*", 
       RowBox[{"F1", "[", "r11", "]"}]}], "-", 
      RowBox[{
       RowBox[{"1", "/", "r11"}], "*", "k", "*", "qf", "*", 
       RowBox[{"F2", "[", "r11", "]"}]}], "-", 
      RowBox[{
       RowBox[{"1", "/", "r11"}], "*", "\[ImaginaryI]", "*", 
       RowBox[{"k", "^", "2"}], "*", 
       RowBox[{"G1", "[", "r11", "]"}]}], "+", 
      RowBox[{"\[ImaginaryI]", "*", 
       RowBox[{"k", "^", "2"}], "*", "qv", "*", 
       RowBox[{"G2", "[", "r11", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Par6", "[", "r12_", "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"k", "^", "2"}], "*", "qf", "*", 
       RowBox[{"F2", "[", "r12", "]"}]}], "-", 
      RowBox[{"\[ImaginaryI]", "*", "k", "*", 
       RowBox[{"qv", "^", "2"}], "*", 
       RowBox[{"G1", "[", "r12", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Par7", "[", "r13_", "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"1", "/", "r13"}], "*", 
       RowBox[{"qf", "^", "2"}], "*", 
       RowBox[{"F1", "[", "r13", "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"qf", "^", "2"}], "-", 
         RowBox[{"2", "/", 
          RowBox[{"r13", "^", "2"}]}]}], ")"}], "*", "qf", "*", 
       RowBox[{"F2", "[", "r13", "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"qv", "^", "2"}], "-", 
         RowBox[{"2", "/", 
          RowBox[{"r13", "^", "2"}]}]}], ")"}], "*", "\[ImaginaryI]", "*", 
       "k", "*", 
       RowBox[{"G1", "[", "r13", "]"}]}], "+", 
      RowBox[{
       RowBox[{"1", "/", "r13"}], "*", "\[ImaginaryI]", "*", "k", "*", "qv", 
       "*", 
       RowBox[{"G2", "[", "r13", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Par8", "[", "r14_", "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"k", "^", "2"}], "*", "qf", "*", 
       RowBox[{"F2", "[", "r14", "]"}]}], "+", 
      RowBox[{"\[ImaginaryI]", "*", 
       RowBox[{"k", "^", "3"}], "*", 
       RowBox[{"G1", "[", "r14", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Par9", "[", "r15_", "]"}], "=", 
     RowBox[{
      RowBox[{"k", "*", 
       RowBox[{"qf", "^", "2"}], "*", 
       RowBox[{"F1", "[", "r15", "]"}]}], "-", 
      RowBox[{
       RowBox[{"1", "/", "r15"}], "*", "k", "*", "qf", "*", 
       RowBox[{"F2", "[", "r15", "]"}]}], "+", 
      RowBox[{
       RowBox[{"1", "/", "r15"}], "*", "\[ImaginaryI]", "*", 
       RowBox[{"qv", "^", "2"}], "*", 
       RowBox[{"G1", "[", "r15", "]"}]}], "-", 
      RowBox[{"\[ImaginaryI]", "*", 
       RowBox[{"qv", "^", "3"}], "*", 
       RowBox[{"G2", "[", "r15", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Par10", "[", "r16_", "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"k", "^", "3"}], "*", 
       RowBox[{"F1", "[", "r16", "]"}]}], "-", 
      RowBox[{"\[ImaginaryI]", "*", 
       RowBox[{"k", "^", "2"}], "*", "qv", "*", 
       RowBox[{"G2", "[", "r16", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ParR", "[", "r17_", "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "qf"}], "*", 
       RowBox[{"F2", "[", "r17", "]"}]}], "-", 
      RowBox[{"\[ImaginaryI]", "*", "k", "*", 
       RowBox[{"G1", "[", "r17", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ParZ", "[", "r18_", "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "k"}], "*", 
       RowBox[{"F1", "[", "r18", "]"}]}], "+", 
      RowBox[{"\[ImaginaryI]", "*", "qv", "*", 
       RowBox[{"G2", "[", "r18", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"source", " ", "terms"}], ",", " ", 
     RowBox[{"given", " ", "in", " ", "appendix", " ", "B"}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Rr", "[", "r19_", "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"Conjugate", "[", 
        RowBox[{"Par2", "[", "r19", "]"}], "]"}], "*", 
       RowBox[{"Par1", "[", "r19", "]"}]}], "+", 
      RowBox[{
       RowBox[{"Conjugate", "[", 
        RowBox[{"ParR", "[", "r19", "]"}], "]"}], "*", 
       RowBox[{"Par5", "[", "r19", "]"}]}], "+", 
      RowBox[{
       RowBox[{"Conjugate", "[", 
        RowBox[{"Par4", "[", "r19", "]"}], "]"}], "*", 
       RowBox[{"Par2", "[", "r19", "]"}]}], "+", 
      RowBox[{
       RowBox[{"Conjugate", "[", 
        RowBox[{"ParZ", "[", "r19", "]"}], "]"}], "*", 
       RowBox[{"Par8", "[", "r19", "]"}]}], "-", 
      RowBox[{
       RowBox[{"Conjugate", "[", 
        RowBox[{"Par1", "[", "r19", "]"}], "]"}], "*", 
       RowBox[{"Par3", "[", "r19", "]"}]}], "-", 
      RowBox[{
       RowBox[{"Conjugate", "[", 
        RowBox[{"ParR", "[", "r19", "]"}], "]"}], "*", 
       RowBox[{"Par9", "[", "r19", "]"}]}], "-", 
      RowBox[{
       RowBox[{"Conjugate", "[", 
        RowBox[{"Par3", "[", "r19", "]"}], "]"}], "*", 
       RowBox[{"Par4", "[", "r19", "]"}]}], "-", 
      RowBox[{
       RowBox[{"Conjugate", "[", 
        RowBox[{"ParZ", "[", "r19", "]"}], "]"}], "*", 
       RowBox[{"Par6", "[", "r19", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
     RowBox[{"Ri", "[", "r20_", "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Conjugate", "[", 
         RowBox[{"Par2", "[", "r20", "]"}], "]"}]}], "*", 
       RowBox[{"Par1", "[", "r20", "]"}]}], "+", 
      RowBox[{
       RowBox[{"Conjugate", "[", 
        RowBox[{"ParR", "[", "r20", "]"}], "]"}], "*", 
       RowBox[{"Par5", "[", "r20", "]"}]}], "+", 
      RowBox[{
       RowBox[{"Conjugate", "[", 
        RowBox[{"Par4", "[", "r20", "]"}], "]"}], "*", 
       RowBox[{"Par2", "[", "r20", "]"}]}], "-", 
      RowBox[{
       RowBox[{"Conjugate", "[", 
        RowBox[{"ParZ", "[", "r20", "]"}], "]"}], "*", 
       RowBox[{"Par8", "[", "r20", "]"}]}], "-", 
      RowBox[{
       RowBox[{"Conjugate", "[", 
        RowBox[{"Par1", "[", "r20", "]"}], "]"}], "*", 
       RowBox[{"Par3", "[", "r20", "]"}]}], "-", 
      RowBox[{
       RowBox[{"Conjugate", "[", 
        RowBox[{"ParR", "[", "r20", "]"}], "]"}], "*", 
       RowBox[{"Par9", "[", "r20", "]"}]}], "+", 
      RowBox[{
       RowBox[{"Conjugate", "[", 
        RowBox[{"Par3", "[", "r20", "]"}], "]"}], "*", 
       RowBox[{"Par4", "[", "r20", "]"}]}], "+", 
      RowBox[{
       RowBox[{"Conjugate", "[", 
        RowBox[{"ParZ", "[", "r20", "]"}], "]"}], "*", 
       RowBox[{"Par6", "[", "r20", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
     RowBox[{"Kr", "[", "r21_", "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"Conjugate", "[", 
        RowBox[{"Par2", "[", "r21", "]"}], "]"}], "*", 
       RowBox[{"Par1", "[", "r21", "]"}]}], "+", 
      RowBox[{
       RowBox[{"Conjugate", "[", 
        RowBox[{"ParR", "[", "r21", "]"}], "]"}], "*", 
       RowBox[{"Par5", "[", "r21", "]"}]}], "+", 
      RowBox[{
       RowBox[{"Conjugate", "[", 
        RowBox[{"Par2", "[", "r21", "]"}], "]"}], "*", 
       RowBox[{"Par4", "[", "r21", "]"}]}], "+", 
      RowBox[{
       RowBox[{"Conjugate", "[", 
        RowBox[{"ParR", "[", "r21", "]"}], "]"}], "*", 
       RowBox[{"Par10", "[", "r21", "]"}]}], "-", 
      RowBox[{
       RowBox[{"Conjugate", "[", 
        RowBox[{"Par3", "[", "r21", "]"}], "]"}], "*", 
       RowBox[{"Par1", "[", "r21", "]"}]}], "-", 
      RowBox[{
       RowBox[{"Conjugate", "[", 
        RowBox[{"ParZ", "[", "r21", "]"}], "]"}], "*", 
       RowBox[{"Par7", "[", "r21", "]"}]}], "-", 
      RowBox[{
       RowBox[{"Conjugate", "[", 
        RowBox[{"Par3", "[", "r21", "]"}], "]"}], "*", 
       RowBox[{"Par4", "[", "r21", "]"}]}], "-", 
      RowBox[{
       RowBox[{"Conjugate", "[", 
        RowBox[{"ParZ", "[", "r21", "]"}], "]"}], "*", 
       RowBox[{"Par6", "[", "r21", "]"}]}], "+", 
      RowBox[{
       RowBox[{"1", "/", "r21"}], "*", 
       RowBox[{"Par2", "[", "r21", "]"}], "*", 
       RowBox[{"Conjugate", "[", 
        RowBox[{"ParR", "[", "r21", "]"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"1", "/", "r21"}], "*", 
       RowBox[{"ParR", "[", "r21", "]"}], "*", 
       RowBox[{"Conjugate", "[", 
        RowBox[{"Par2", "[", "r21", "]"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"1", "/", "r21"}], "*", 
       RowBox[{"Par3", "[", "r21", "]"}], "*", 
       RowBox[{"Conjugate", "[", 
        RowBox[{"ParR", "[", "r21", "]"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"1", "/", "r21"}], "*", 
       RowBox[{"ParZ", "[", "r21", "]"}], "*", 
       RowBox[{"Conjugate", "[", 
        RowBox[{"Par1", "[", "r21", "]"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"r21", "^", "2"}], ")"}]}], "*", 
       RowBox[{"ParZ", "[", "r21", "]"}], "*", 
       RowBox[{"Conjugate", "[", 
        RowBox[{"ParR", "[", "r21", "]"}], "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Ki", "[", "r22_", "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Conjugate", "[", 
         RowBox[{"Par2", "[", "r22", "]"}], "]"}]}], "*", 
       RowBox[{"Par1", "[", "r22", "]"}]}], "+", 
      RowBox[{
       RowBox[{"Conjugate", "[", 
        RowBox[{"ParR", "[", "r22", "]"}], "]"}], "*", 
       RowBox[{"Par5", "[", "r22", "]"}]}], "-", 
      RowBox[{
       RowBox[{"Conjugate", "[", 
        RowBox[{"Par2", "[", "r22", "]"}], "]"}], "*", 
       RowBox[{"Par4", "[", "r22", "]"}]}], "+", 
      RowBox[{
       RowBox[{"Conjugate", "[", 
        RowBox[{"ParR", "[", "r22", "]"}], "]"}], "*", 
       RowBox[{"Par10", "[", "r22", "]"}]}], "+", 
      RowBox[{
       RowBox[{"Conjugate", "[", 
        RowBox[{"Par3", "[", "r22", "]"}], "]"}], "*", 
       RowBox[{"Par1", "[", "r22", "]"}]}], "+", 
      RowBox[{
       RowBox[{"Conjugate", "[", 
        RowBox[{"ParZ", "[", "r22", "]"}], "]"}], "*", 
       RowBox[{"Par7", "[", "r22", "]"}]}], "+", 
      RowBox[{
       RowBox[{"Conjugate", "[", 
        RowBox[{"Par3", "[", "r22", "]"}], "]"}], "*", 
       RowBox[{"Par4", "[", "r22", "]"}]}], "+", 
      RowBox[{
       RowBox[{"Conjugate", "[", 
        RowBox[{"ParZ", "[", "r22", "]"}], "]"}], "*", 
       RowBox[{"Par6", "[", "r22", "]"}]}], "+", 
      RowBox[{
       RowBox[{"1", "/", "r22"}], "*", 
       RowBox[{"Par2", "[", "r22", "]"}], "*", 
       RowBox[{"Conjugate", "[", 
        RowBox[{"ParR", "[", "r22", "]"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"1", "/", "r22"}], "*", 
       RowBox[{"ParR", "[", "r22", "]"}], "*", 
       RowBox[{"Conjugate", "[", 
        RowBox[{"Par2", "[", "r22", "]"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"1", "/", "r22"}], "*", 
       RowBox[{"Par3", "[", "r22", "]"}], "*", 
       RowBox[{"Conjugate", "[", 
        RowBox[{"ParR", "[", "r22", "]"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"1", "/", "r22"}], "*", 
       RowBox[{"ParZ", "[", "r22", "]"}], "*", 
       RowBox[{"Conjugate", "[", 
        RowBox[{"Par1", "[", "r22", "]"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"r22", "^", "2"}], ")"}]}], "*", 
       RowBox[{"ParZ", "[", "r22", "]"}], "*", 
       RowBox[{"Conjugate", "[", 
        RowBox[{"ParR", "[", "r22", "]"}], "]"}]}]}]}], ";"}]}]}]], "Input",
 CellLabel->"In[44]:=",ExpressionUUID->"c345bc54-e592-4102-9c24-1760eb24d60c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "source", " ", "terms", " ", "related", " ", "to", " ", "the", " ", 
    "scalar", " ", "velocity", " ", "potential"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Mr", "[", "r23_", "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"J0", "[", 
         RowBox[{
          RowBox[{"Conjugate", "[", "qf", "]"}], "*", "r23"}], "]"}]}], "*", 
       RowBox[{"kf", "^", "2"}], "*", "A1", "*", 
       RowBox[{"J0", "[", 
        RowBox[{"qf", "*", "r23"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"Conjugate", "[", "qf", "]"}], "*", "qf", "*", "A1", "*", 
       RowBox[{"J1", "[", 
        RowBox[{
         RowBox[{"Conjugate", "[", "qf", "]"}], "*", "r23"}], "]"}], "*", 
       RowBox[{"J1", "[", 
        RowBox[{"qf", "*", "r23"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"Conjugate", "[", "qf", "]"}], "*", 
       RowBox[{"J1", "[", 
        RowBox[{
         RowBox[{"Conjugate", "[", "qf", "]"}], "*", "r23"}], "]"}], "*", 
       "\[ImaginaryI]", "*", "k", "*", "B1", "*", 
       RowBox[{"J1", "[", 
        RowBox[{"qv", "*", "r23"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"Conjugate", "[", "k", "]"}], "*", "k", "*", "A1", "*", 
       RowBox[{"J0", "[", 
        RowBox[{
         RowBox[{"Conjugate", "[", "qf", "]"}], "*", "r23"}], "]"}], "*", 
       RowBox[{"J0", "[", 
        RowBox[{"qf", "*", "r23"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"Conjugate", "[", "k", "]"}], "*", 
       RowBox[{"J0", "[", 
        RowBox[{
         RowBox[{"Conjugate", "[", "qf", "]"}], "*", "r23"}], "]"}], "*", 
       "\[ImaginaryI]", "*", "qv", "*", "B1", "*", 
       RowBox[{"J0", "[", 
        RowBox[{"qv", "*", "r23"}], "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Mi", "[", "r24_", "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"J0", "[", 
         RowBox[{
          RowBox[{"Conjugate", "[", "qf", "]"}], "*", "r24"}], "]"}]}], "*", 
       RowBox[{"kf", "^", "2"}], "*", "A1", "*", 
       RowBox[{"J0", "[", 
        RowBox[{"qf", "*", "r24"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"Conjugate", "[", "qf", "]"}], "*", "qf", "*", "A1", "*", 
       RowBox[{"J1", "[", 
        RowBox[{
         RowBox[{"Conjugate", "[", "qf", "]"}], "*", "r24"}], "]"}], "*", 
       RowBox[{"J1", "[", 
        RowBox[{"qf", "*", "r24"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"Conjugate", "[", "qf", "]"}], "*", 
       RowBox[{"J1", "[", 
        RowBox[{
         RowBox[{"Conjugate", "[", "qf", "]"}], "*", "r24"}], "]"}], "*", 
       "\[ImaginaryI]", "*", "k", "*", "B1", "*", 
       RowBox[{"J1", "[", 
        RowBox[{"qv", "*", "r24"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"Conjugate", "[", "k", "]"}], "*", "k", "*", "A1", "*", 
       RowBox[{"J0", "[", 
        RowBox[{
         RowBox[{"Conjugate", "[", "qf", "]"}], "*", "r24"}], "]"}], "*", 
       RowBox[{"J0", "[", 
        RowBox[{"qf", "*", "r24"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"Conjugate", "[", "k", "]"}], "*", 
       RowBox[{"J0", "[", 
        RowBox[{
         RowBox[{"Conjugate", "[", "qf", "]"}], "*", "r24"}], "]"}], "*", 
       "\[ImaginaryI]", "*", "qv", "*", "B1", "*", 
       RowBox[{"J0", "[", 
        RowBox[{"qv", "*", "r24"}], "]"}]}]}]}], ";"}]}]}]], "Input",
 CellLabel->
  "In[60]:=",ExpressionUUID->"11dca53e-7b9a-415b-8543-81607e563d75"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Finite Hankel transform", \
"Section",ExpressionUUID->"13f9134f-b4c1-4856-80de-761d8c44b5e1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "positive", " ", "roots", " ", "associated", " ", "with", " ", "the", " ", 
    "finite", " ", "Hankel", " ", "transform"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Xi]", "[", "n_", "]"}], "=", 
    RowBox[{
     RowBox[{"BesselJZero", "[", 
      RowBox[{"1", ",", "n"}], "]"}], "/", "a"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"eq", ".", " ", "4.20"}], "*)"}]}]], "Input",
 CellLabel->
  "In[62]:=",ExpressionUUID->"88cd5e0b-53e4-4ca4-b0e3-f3f98d86279b"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Unknown constants at the second order", \
"Section",ExpressionUUID->"55304c66-7e8b-48e6-b125-2791b00f58e7"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
  "constants", " ", "related", " ", "to", " ", "the", " ", "scalar", " ", 
   "velocity", " ", "potential"}], "*)"}]], "Input",
 CellLabel->"In[64]:=",ExpressionUUID->"2d7c8d71-7c45-4fa3-ad50-113515807188"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"C5", "=", 
   RowBox[{
    RowBox[{
     FractionBox["Pi", "2"], "*", 
     RowBox[{"NIntegrate", "[", 
      RowBox[{
       RowBox[{"r2", "*", 
        RowBox[{"Mr", "[", "r2", "]"}], "*", 
        RowBox[{"Y0", "[", 
         RowBox[{
          RowBox[{"-", "2"}], "*", "\[ImaginaryI]", "*", "kR", "*", "r2"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"r2", ",", "0", ",", "a"}], "}"}], ",", 
       RowBox[{"Method", "\[Rule]", "\"\<MultiPeriodic\>\""}]}], "]"}]}], "+", 
    RowBox[{
     FractionBox["Pi", "2"], "*", 
     FractionBox[
      RowBox[{"Y1", "[", 
       RowBox[{
        RowBox[{"-", "2"}], "*", "\[ImaginaryI]", "*", "kR", "*", "a"}], 
       "]"}], 
      RowBox[{"J1", "[", 
       RowBox[{"2", "*", "\[ImaginaryI]", "*", "kR", "*", "a"}], "]"}]], "*", 
     
     RowBox[{"NIntegrate", "[", 
      RowBox[{
       RowBox[{"r2", "*", 
        RowBox[{"Mr", "[", "r2", "]"}], "*", 
        RowBox[{"J0", "[", 
         RowBox[{"2", "*", "\[ImaginaryI]", "*", "kR", "*", "r2"}], "]"}]}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"r2", ",", "0", ",", "a"}], "}"}], ",", 
       RowBox[{"Method", "\[Rule]", "\"\<MultiPeriodic\>\""}]}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"C6", "=", 
   RowBox[{
    RowBox[{
     FractionBox["Pi", "2"], "*", 
     RowBox[{"NIntegrate", "[", 
      RowBox[{
       RowBox[{"r3", "*", 
        RowBox[{"Mi", "[", "r3", "]"}], "*", 
        RowBox[{"Y0", "[", 
         RowBox[{"2", "*", "kI", "*", "r3"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"r3", ",", "0", ",", "a"}], "}"}], ",", 
       RowBox[{"Method", "\[Rule]", "\"\<MultiPeriodic\>\""}]}], "]"}]}], "-", 
    RowBox[{
     FractionBox["Pi", "2"], "*", 
     FractionBox[
      RowBox[{"Y1", "[", 
       RowBox[{"2", "*", "kI", "*", "a"}], "]"}], 
      RowBox[{"J1", "[", 
       RowBox[{"2", "*", "kI", "*", "a"}], "]"}]], "*", 
     RowBox[{"NIntegrate", "[", 
      RowBox[{
       RowBox[{"r3", "*", 
        RowBox[{"Mi", "[", "r3", "]"}], "*", 
        RowBox[{"J0", "[", 
         RowBox[{"2", "*", "kI", "*", "r3"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"r3", ",", "0", ",", "a"}], "}"}], ",", 
       RowBox[{"Method", "\[Rule]", "\"\<MultiPeriodic\>\""}]}], "]"}]}]}]}], 
  ";"}]}], "Input",
 CellLabel->"In[65]:=",ExpressionUUID->"2847af0c-52d9-4cce-961a-16ca5cb481db"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"C1", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"pA", "*", 
        RowBox[{"etaf", "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"rhof", "^", "2"}], "*", 
           RowBox[{"cf", "^", "2"}]}], ")"}]}], "*", "kR", "*", 
        RowBox[{"J0", "[", 
         RowBox[{"2", "*", "I", "*", "kR", "*", "a"}], "]"}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Pi", "/", "2"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"Y0", "[", 
              RowBox[{
               RowBox[{"-", "2"}], "*", "I", "*", "kR", "*", "a"}], "]"}], 
             "/", 
             RowBox[{"J0", "[", 
              RowBox[{"2", "*", "I", "*", "kR", "*", "a"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"Y1", "[", 
              RowBox[{
               RowBox[{"-", "2"}], "*", "I", "*", "kR", "*", "a"}], "]"}], 
             "/", 
             RowBox[{"J1", "[", 
              RowBox[{"2", "*", "I", "*", "kR", "*", "a"}], "]"}]}]}], ")"}], 
          "*", 
          RowBox[{"NIntegrate", "[", 
           RowBox[{
            RowBox[{"r2", "*", 
             RowBox[{"Mr", "[", "r2", "]"}], "*", 
             RowBox[{"J0", "[", 
              RowBox[{"2", "*", "I", "*", "kR", "*", "r2"}], "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"r2", ",", "0", ",", "a"}], "}"}], ",", 
            RowBox[{"Method", "->", "\"\<MultiPeriodic\>\""}]}], "]"}]}], 
         ")"}]}], "+", 
       RowBox[{
        RowBox[{"2", "/", 
         RowBox[{"a", "^", "2"}]}], "*", 
        RowBox[{"ParallelSum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"\[Xi]", "[", "i", "]"}], "/", 
            RowBox[{"J2", "[", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "i", "]"}], "*", "a"}], "]"}]}], "*", 
           RowBox[{"1", "/", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"\[Xi]", "[", "i", "]"}], "^", "2"}], "+", 
               RowBox[{"4", "*", 
                RowBox[{"kR", "^", "2"}]}]}], ")"}], "^", "2"}]}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"NIntegrate", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"Rr", "[", "r2", "]"}], ")"}], "*", "r2", "*", 
                RowBox[{"J1", "[", 
                 RowBox[{
                  RowBox[{"\[Xi]", "[", "i", "]"}], "*", "r2"}], "]"}]}], ",", 
               RowBox[{"{", 
                RowBox[{"r2", ",", "0", ",", "a"}], "}"}], ",", 
               RowBox[{"Method", "->", "\"\<MultiPeriodic\>\""}]}], "]"}], 
             "+", 
             RowBox[{"NIntegrate", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"Kr", "[", "r2", "]"}], ")"}], "*", "r2", "*", 
                RowBox[{"J1", "[", 
                 RowBox[{
                  RowBox[{"\[Xi]", "[", "i", "]"}], "*", "r2"}], "]"}]}], ",", 
               RowBox[{"{", 
                RowBox[{"r2", ",", "0", ",", "a"}], "}"}], ",", 
               RowBox[{"Method", "->", "\"\<MultiPeriodic\>\""}]}], "]"}]}], 
            ")"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "iMax"}], "}"}]}], "]"}]}]}], ")"}], 
     "*", 
     RowBox[{"1", "/", 
      RowBox[{"ParallelSum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", "*", 
           RowBox[{
            RowBox[{"\[Xi]", "[", "i", "]"}], "^", "2"}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"a", "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"\[Xi]", "[", "i", "]"}], "^", "2"}], "+", 
              RowBox[{"4", "*", 
               RowBox[{"kR", "^", "2"}]}]}], ")"}], "^", "2"}]}], ")"}]}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "iMax"}], "}"}]}], "]"}]}]}]}], ";"}], 
  "\n"}], "\n", 
 RowBox[{
  RowBox[{"C3", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"pA", "*", 
       RowBox[{"etaf", "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"rhof", "^", "2"}], "*", 
          RowBox[{"cf", "^", "2"}]}], ")"}]}], "*", "I", "*", "kI", "*", 
       RowBox[{"J0", "[", 
        RowBox[{"2", "*", "kI", "*", "a"}], "]"}], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Pi", "/", "2"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"Y0", "[", 
             RowBox[{"2", "*", "kI", "*", "a"}], "]"}], "/", 
            RowBox[{"J0", "[", 
             RowBox[{"2", "*", "kI", "*", "a"}], "]"}]}], "-", 
           RowBox[{
            RowBox[{"Y1", "[", 
             RowBox[{"2", "*", "kI", "*", "a"}], "]"}], "/", 
            RowBox[{"J1", "[", 
             RowBox[{"2", "*", "kI", "*", "a"}], "]"}]}]}], ")"}], "*", 
         RowBox[{"NIntegrate", "[", 
          RowBox[{
           RowBox[{"r3", "*", 
            RowBox[{"Mi", "[", "r3", "]"}], "*", 
            RowBox[{"J0", "[", 
             RowBox[{"2", "*", "kI", "*", "r3"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"r3", ",", "0", ",", "a"}], "}"}], ",", 
           RowBox[{"Method", "->", "\"\<MultiPeriodic\>\""}]}], "]"}]}], 
        ")"}]}], "+", 
      RowBox[{
       RowBox[{"2", "/", 
        RowBox[{"a", "^", "2"}]}], "*", 
       RowBox[{"ParallelSum", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"\[Xi]", "[", "i", "]"}], "/", 
           RowBox[{"J2", "[", 
            RowBox[{
             RowBox[{"\[Xi]", "[", "i", "]"}], "*", "a"}], "]"}]}], "*", 
          RowBox[{"1", "/", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"\[Xi]", "[", "i", "]"}], "^", "2"}], "-", 
              RowBox[{"4", "*", 
               RowBox[{"kI", "^", "2"}]}]}], ")"}], "^", "2"}]}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"NIntegrate", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"Ri", "[", "r3", "]"}], ")"}], "*", "r3", "*", 
               RowBox[{"J1", "[", 
                RowBox[{
                 RowBox[{"\[Xi]", "[", "i", "]"}], "*", "r3"}], "]"}]}], ",", 
              
              RowBox[{"{", 
               RowBox[{"r3", ",", "0", ",", "a"}], "}"}], ",", 
              RowBox[{"Method", "->", "\"\<MultiPeriodic\>\""}]}], "]"}], "+", 
            RowBox[{"NIntegrate", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"Ki", "[", "r3", "]"}], ")"}], "*", "r3", "*", 
               RowBox[{"J1", "[", 
                RowBox[{
                 RowBox[{"\[Xi]", "[", "i", "]"}], "*", "r3"}], "]"}]}], ",", 
              
              RowBox[{"{", 
               RowBox[{"r3", ",", "0", ",", "a"}], "}"}], ",", 
              RowBox[{"Method", "->", "\"\<MultiPeriodic\>\""}]}], "]"}]}], 
           ")"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "iMax"}], "}"}]}], "]"}]}]}], ")"}], 
    "*", 
    RowBox[{"1", "/", 
     RowBox[{"ParallelSum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2", "*", 
          RowBox[{
           RowBox[{"\[Xi]", "[", "i", "]"}], "^", "2"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"a", "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"\[Xi]", "[", "i", "]"}], "^", "2"}], "-", 
             RowBox[{"4", "*", 
              RowBox[{"kI", "^", "2"}]}]}], ")"}], "^", "2"}]}], ")"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "iMax"}], "}"}]}], "]"}]}]}]}], 
  ";"}]}], "Input",ExpressionUUID->"c36bc378-0d58-4c05-8b63-18d36b0b8b33"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Second - order (streaming) fields", \
"Section",ExpressionUUID->"babed4aa-b2a4-4df5-bc59-db8bfeaadbc5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"s1", "[", "r_", "]"}], ":=", 
   RowBox[{
    RowBox[{"2", "/", 
     RowBox[{"a", "^", "2"}]}], "*", 
    RowBox[{"ParallelSum", "[", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"J1", "[", 
         RowBox[{
          RowBox[{"\[Xi]", "[", "i", "]"}], "*", "r"}], "]"}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"J2", "[", 
           RowBox[{
            RowBox[{"\[Xi]", "[", "i", "]"}], "*", "a"}], "]"}], ")"}], "^", 
         "2"}]], "*", 
       FractionBox["1", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"\[Xi]", "[", "i", "]"}], "^", "2"}], "+", 
           RowBox[{"4", "*", 
            RowBox[{"kR", "^", "2"}]}]}], ")"}], "^", "2"}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"NIntegrate", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"Rr", "[", "r2", "]"}], ")"}], "*", "r2", "*", 
            RowBox[{"J1", "[", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "i", "]"}], "*", "r2"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"r2", ",", "0", ",", "a"}], "}"}], ",", 
           RowBox[{"Method", "\[Rule]", "\"\<MultiPeriodic\>\""}]}], "]"}], 
         "+", 
         RowBox[{"NIntegrate", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"Kr", "[", "r2", "]"}], ")"}], "*", "r2", "*", 
            RowBox[{"J1", "[", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "i", "]"}], "*", "r2"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"r2", ",", "0", ",", "a"}], "}"}], ",", 
           RowBox[{"Method", "\[Rule]", "\"\<MultiPeriodic\>\""}]}], "]"}], 
         "+", 
         RowBox[{"a", "*", 
          RowBox[{"\[Xi]", "[", "i", "]"}], "*", 
          RowBox[{"(", 
           RowBox[{"-", 
            RowBox[{"J2", "[", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "i", "]"}], "*", "a"}], "]"}]}], ")"}], 
          "*", "C1"}]}], ")"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "iMax"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"s2", "[", "r_", "]"}], ":=", 
   RowBox[{
    RowBox[{"2", "/", 
     RowBox[{"a", "^", "2"}]}], "*", 
    RowBox[{"ParallelSum", "[", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"J1", "[", 
         RowBox[{
          RowBox[{"\[Xi]", "[", "i", "]"}], "*", "r"}], "]"}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"J2", "[", 
           RowBox[{
            RowBox[{"\[Xi]", "[", "i", "]"}], "*", "a"}], "]"}], ")"}], "^", 
         "2"}]], "*", 
       FractionBox["1", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"\[Xi]", "[", "i", "]"}], "^", "2"}], "-", 
           RowBox[{"4", "*", 
            RowBox[{"kI", "^", "2"}]}]}], ")"}], "^", "2"}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"NIntegrate", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"Ri", "[", "r2", "]"}], ")"}], "*", "r2", "*", 
            RowBox[{"J1", "[", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "i", "]"}], "*", "r2"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"r2", ",", "0", ",", "a"}], "}"}], ",", 
           RowBox[{"Method", "\[Rule]", "\"\<MultiPeriodic\>\""}]}], "]"}], 
         "+", 
         RowBox[{"NIntegrate", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"Ki", "[", "r2", "]"}], ")"}], "*", "r2", "*", 
            RowBox[{"J1", "[", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "i", "]"}], "*", "r2"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"r2", ",", "0", ",", "a"}], "}"}], ",", 
           RowBox[{"Method", "\[Rule]", "\"\<MultiPeriodic\>\""}]}], "]"}], 
         "+", 
         RowBox[{"a", "*", 
          RowBox[{"\[Xi]", "[", "i", "]"}], "*", 
          RowBox[{"(", 
           RowBox[{"-", 
            RowBox[{"J2", "[", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "i", "]"}], "*", "a"}], "]"}]}], ")"}], 
          "*", "C3"}]}], ")"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "iMax"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ds1", "[", "r_", "]"}], ":=", 
   RowBox[{
    RowBox[{"2", "/", 
     RowBox[{"a", "^", "2"}]}], "*", 
    RowBox[{"ParallelSum", "[", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"1", "/", "r"}], "*", 
          RowBox[{"J1", "[", 
           RowBox[{
            RowBox[{"\[Xi]", "[", "i", "]"}], "*", "r"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"J2", "[", 
           RowBox[{
            RowBox[{"\[Xi]", "[", "i", "]"}], "*", "r"}], "]"}], "*", 
          RowBox[{"\[Xi]", "[", "i", "]"}]}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"J2", "[", 
           RowBox[{
            RowBox[{"\[Xi]", "[", "i", "]"}], "*", "a"}], "]"}], ")"}], "^", 
         "2"}]], "*", 
       FractionBox["1", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"\[Xi]", "[", "i", "]"}], "^", "2"}], "+", 
           RowBox[{"4", "*", 
            RowBox[{"kR", "^", "2"}]}]}], ")"}], "^", "2"}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"NIntegrate", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"Rr", "[", "r4", "]"}], ")"}], "*", "r4", "*", 
            RowBox[{"J1", "[", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "i", "]"}], "*", "r4"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"r4", ",", "0", ",", "a"}], "}"}], ",", 
           RowBox[{"Method", "\[Rule]", "\"\<MultiPeriodic\>\""}]}], "]"}], 
         "+", 
         RowBox[{"NIntegrate", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"Kr", "[", "r4", "]"}], ")"}], "*", "r4", "*", 
            RowBox[{"J1", "[", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "i", "]"}], "*", "r4"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"r4", ",", "0", ",", "a"}], "}"}], ",", 
           RowBox[{"Method", "\[Rule]", "\"\<MultiPeriodic\>\""}]}], "]"}], 
         "+", 
         RowBox[{"a", "*", 
          RowBox[{"\[Xi]", "[", "i", "]"}], "*", 
          RowBox[{"(", 
           RowBox[{"-", 
            RowBox[{"J2", "[", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "i", "]"}], "*", "a"}], "]"}]}], ")"}], 
          "*", "C1"}]}], ")"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "iMax"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Ds2", "[", "r_", "]"}], ":=", 
    RowBox[{
     RowBox[{"2", "/", 
      RowBox[{"a", "^", "2"}]}], "*", 
     RowBox[{"ParallelSum", "[", 
      RowBox[{
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"1", "/", "r"}], "*", 
           RowBox[{"J1", "[", 
            RowBox[{
             RowBox[{"\[Xi]", "[", "i", "]"}], "*", "r"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"J2", "[", 
            RowBox[{
             RowBox[{"\[Xi]", "[", "i", "]"}], "*", "r"}], "]"}], "*", 
           RowBox[{"\[Xi]", "[", "i", "]"}]}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"J2", "[", 
            RowBox[{
             RowBox[{"\[Xi]", "[", "i", "]"}], "*", "a"}], "]"}], ")"}], "^", 
          "2"}]], "*", 
        FractionBox["1", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"\[Xi]", "[", "i", "]"}], "^", "2"}], "-", 
            RowBox[{"4", "*", 
             RowBox[{"kI", "^", "2"}]}]}], ")"}], "^", "2"}]], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"NIntegrate", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"Ri", "[", "r5", "]"}], ")"}], "*", "r5", "*", 
             RowBox[{"J1", "[", 
              RowBox[{
               RowBox[{"\[Xi]", "[", "i", "]"}], "*", "r5"}], "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"r5", ",", "0", ",", "a"}], "}"}], ",", 
            RowBox[{"Method", "\[Rule]", "\"\<MultiPeriodic\>\""}]}], "]"}], 
          "+", 
          RowBox[{"NIntegrate", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"Ki", "[", "r5", "]"}], ")"}], "*", "r5", "*", 
             RowBox[{"J1", "[", 
              RowBox[{
               RowBox[{"\[Xi]", "[", "i", "]"}], "*", "r5"}], "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"r5", ",", "0", ",", "a"}], "}"}], ",", 
            RowBox[{"Method", "\[Rule]", "\"\<MultiPeriodic\>\""}]}], "]"}], 
          "+", 
          RowBox[{"a", "*", 
           RowBox[{"\[Xi]", "[", "i", "]"}], "*", 
           RowBox[{"(", 
            RowBox[{"-", 
             RowBox[{"J2", "[", 
              RowBox[{
               RowBox[{"\[Xi]", "[", "i", "]"}], "*", "a"}], "]"}]}], ")"}], 
           "*", "C3"}]}], ")"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "iMax"}], "}"}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"additions", " ", "due", " ", "to", " ", "the", " ", "full", " ", 
    RowBox[{"cont", ".", " ", "equation"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"v2rDiv", "[", 
    RowBox[{
     RowBox[{"r_", "?", "NumericQ"}], ",", "z_"}], "]"}], ":=", 
   RowBox[{
    FractionBox[
     RowBox[{"-", "pA"}], 
     RowBox[{"2", "*", "rhof", "*", 
      RowBox[{"cf", "^", "2"}]}]], "*", 
    RowBox[{"Re", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Cos", "[", 
        RowBox[{"2", "*", "kR", "*", "z"}], "]"}], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Pi", "*", "\[ImaginaryI]", "*", "kR", "*", 
          RowBox[{"J1", "[", 
           RowBox[{"2", "*", "\[ImaginaryI]", "*", "kR", "*", "r"}], "]"}], 
          "*", 
          RowBox[{"NIntegrate", "[", 
           RowBox[{
            RowBox[{"r2", "*", 
             RowBox[{"Mr", "[", "r2", "]"}], "*", 
             RowBox[{"Y0", "[", 
              RowBox[{
               RowBox[{"-", "2"}], "*", "\[ImaginaryI]", "*", "kR", "*", 
               "r2"}], "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"r2", ",", "0", ",", "r"}], "}"}], ",", 
            RowBox[{"Method", "\[Rule]", "\"\<MultiPeriodic\>\""}]}], "]"}]}],
          "+", 
         RowBox[{"Pi", "*", "\[ImaginaryI]", "*", "kR", "*", 
          RowBox[{"Y1", "[", 
           RowBox[{
            RowBox[{"-", "2"}], "*", "\[ImaginaryI]", "*", "kR", "*", "r"}], 
           "]"}], "*", 
          RowBox[{"NIntegrate", "[", 
           RowBox[{
            RowBox[{"r2", "*", 
             RowBox[{"Mr", "[", "r2", "]"}], "*", 
             RowBox[{"J0", "[", 
              RowBox[{"2", "*", "\[ImaginaryI]", "*", "kR", "*", "r2"}], 
              "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"r2", ",", "0", ",", "r"}], "}"}], ",", 
            RowBox[{"Method", "\[Rule]", "\"\<MultiPeriodic\>\""}]}], "]"}]}],
          "-", 
         RowBox[{"2", "*", "\[ImaginaryI]", "*", "kR", "*", "C5", "*", 
          RowBox[{"J1", "[", 
           RowBox[{"2", "*", "\[ImaginaryI]", "*", "kR", "*", "r"}], 
           "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"Cosh", "[", 
        RowBox[{"2", "*", "kI", "*", "z"}], "]"}], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Pi", "*", "kI", "*", 
          RowBox[{"J1", "[", 
           RowBox[{"2", "*", "kI", "*", "r"}], "]"}], "*", 
          RowBox[{"NIntegrate", "[", 
           RowBox[{
            RowBox[{"r2", "*", 
             RowBox[{"Mi", "[", "r2", "]"}], "*", 
             RowBox[{"Y0", "[", 
              RowBox[{"2", "*", "kI", "*", "r2"}], "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"r2", ",", "0", ",", "r"}], "}"}], ",", 
            RowBox[{"Method", "\[Rule]", "\"\<MultiPeriodic\>\""}]}], "]"}]}],
          "-", 
         RowBox[{"Pi", "*", "kI", "*", 
          RowBox[{"Y1", "[", 
           RowBox[{"2", "*", "kI", "*", "r"}], "]"}], "*", 
          RowBox[{"NIntegrate", "[", 
           RowBox[{
            RowBox[{"r2", "*", 
             RowBox[{"Mi", "[", "r2", "]"}], "*", 
             RowBox[{"J0", "[", 
              RowBox[{"2", "*", "kI", "*", "r2"}], "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"r2", ",", "0", ",", "r"}], "}"}], ",", 
            RowBox[{"Method", "\[Rule]", "\"\<MultiPeriodic\>\""}]}], "]"}]}],
          "-", 
         RowBox[{"2", "*", "kI", "*", "C6", "*", 
          RowBox[{"J1", "[", 
           RowBox[{"2", "*", "kI", "*", "r"}], "]"}]}]}], ")"}]}]}], 
     "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"v2zDiv", "[", 
     RowBox[{
      RowBox[{"r_", "?", "NumericQ"}], ",", "z_"}], "]"}], ":=", 
    RowBox[{
     FractionBox[
      RowBox[{"-", "pA"}], 
      RowBox[{"2", "*", "rhof", "*", 
       RowBox[{"cf", "^", "2"}]}]], "*", 
     RowBox[{"Re", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], "*", "kR", "*", 
        RowBox[{"Sin", "[", 
         RowBox[{"2", "*", "kR", "*", "z"}], "]"}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox[
            RowBox[{"-", "Pi"}], "2"], "*", 
           RowBox[{"J0", "[", 
            RowBox[{"2", "*", "\[ImaginaryI]", "*", "kR", "*", "r"}], "]"}], 
           "*", 
           RowBox[{"NIntegrate", "[", 
            RowBox[{
             RowBox[{"r3", "*", 
              RowBox[{"Mr", "[", "r3", "]"}], "*", 
              RowBox[{"Y0", "[", 
               RowBox[{
                RowBox[{"-", "2"}], "*", "\[ImaginaryI]", "*", "kR", "*", 
                "r3"}], "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"r3", ",", "0", ",", "r"}], "}"}], ",", 
             RowBox[{"Method", "\[Rule]", "\"\<MultiPeriodic\>\""}]}], 
            "]"}]}], "+", 
          RowBox[{
           FractionBox["Pi", "2"], "*", 
           RowBox[{"Y0", "[", 
            RowBox[{
             RowBox[{"-", "2"}], "*", "\[ImaginaryI]", "*", "kR", "*", "r"}], 
            "]"}], "*", 
           RowBox[{"NIntegrate", "[", 
            RowBox[{
             RowBox[{"r3", "*", 
              RowBox[{"Mr", "[", "r3", "]"}], "*", 
              RowBox[{"J0", "[", 
               RowBox[{"2", "*", "\[ImaginaryI]", "*", "kR", "*", "r3"}], 
               "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"r3", ",", "0", ",", "r"}], "}"}], ",", 
             RowBox[{"Method", "\[Rule]", "\"\<MultiPeriodic\>\""}]}], 
            "]"}]}], "+", 
          RowBox[{"C5", "*", 
           RowBox[{"J0", "[", 
            RowBox[{"2", "*", "\[ImaginaryI]", "*", "kR", "*", "r"}], 
            "]"}]}]}], ")"}]}], "+", 
       RowBox[{"2", "*", "kI", "*", 
        RowBox[{"Sinh", "[", 
         RowBox[{"2", "*", "kI", "*", "z"}], "]"}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox[
            RowBox[{"-", "Pi"}], "2"], "*", 
           RowBox[{"J0", "[", 
            RowBox[{"2", "*", "kI", "*", "r"}], "]"}], "*", 
           RowBox[{"NIntegrate", "[", 
            RowBox[{
             RowBox[{"r3", "*", 
              RowBox[{"Mi", "[", "r3", "]"}], "*", 
              RowBox[{"Y0", "[", 
               RowBox[{"2", "*", "kI", "*", "r3"}], "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"r3", ",", "0", ",", "r"}], "}"}], ",", 
             RowBox[{"Method", "\[Rule]", "\"\<MultiPeriodic\>\""}]}], 
            "]"}]}], "+", 
          RowBox[{
           FractionBox["Pi", "2"], "*", 
           RowBox[{"Y0", "[", 
            RowBox[{"2", "*", "kI", "*", "r"}], "]"}], "*", 
           RowBox[{"NIntegrate", "[", 
            RowBox[{
             RowBox[{"r3", "*", 
              RowBox[{"Mi", "[", "r3", "]"}], "*", 
              RowBox[{"J0", "[", 
               RowBox[{"2", "*", "kI", "*", "r3"}], "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"r3", ",", "0", ",", "r"}], "}"}], ",", 
             RowBox[{"Method", "\[Rule]", "\"\<MultiPeriodic\>\""}]}], 
            "]"}]}], "+", 
          RowBox[{"C6", "*", 
           RowBox[{"J0", "[", 
            RowBox[{"2", "*", "kI", "*", "r"}], "]"}]}]}], ")"}]}]}], 
      "]"}]}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Eulerian", " ", "streaming", " ", "velocity", " ", "field"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"v2r", "[", 
    RowBox[{"r_", ",", "z_"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"2", "*", "rhof"}], "etaf"], "*", 
     RowBox[{"Re", "[", 
      RowBox[{
       RowBox[{"kR", "*", 
        RowBox[{"Cos", "[", 
         RowBox[{"2", "*", "kR", "*", "z"}], "]"}], "*", 
        RowBox[{"s1", "[", "r", "]"}]}], "+", 
       RowBox[{"\[ImaginaryI]", "*", "kI", "*", 
        RowBox[{"Cosh", "[", 
         RowBox[{"2", "*", "kI", "*", "z"}], "]"}], "*", 
        RowBox[{"s2", "[", "r", "]"}]}]}], "]"}]}], "+", 
    RowBox[{"v2rDiv", "[", 
     RowBox[{"r", ",", "z"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"v2z", "[", 
    RowBox[{"r_", ",", "z_"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["rhof", "etaf"]}], "*", 
     RowBox[{"Re", "[", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"2", "*", "kR", "*", "z"}], "]"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"1", "/", "r"}], "*", 
            RowBox[{"s1", "[", "r", "]"}]}], "+", 
           RowBox[{"Ds1", "[", "r", "]"}]}], ")"}]}], "+", 
        RowBox[{"\[ImaginaryI]", "*", 
         RowBox[{"Sinh", "[", 
          RowBox[{"2", "*", "kI", "*", "z"}], "]"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"1", "/", "r"}], "*", 
            RowBox[{"s2", "[", "r", "]"}]}], "+", 
           RowBox[{"Ds2", "[", "r", "]"}]}], ")"}]}]}], ")"}], "]"}]}], "+", 
    RowBox[{"v2zDiv", "[", 
     RowBox[{"r", ",", "z"}], "]"}]}]}], 
  ";"}]}], "Input",ExpressionUUID->"d07bcc83-faf3-4764-98ff-3e817417e7db"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Lagrangian streaming velocity field", \
"Section",ExpressionUUID->"daba0f31-df50-4575-8705-7fdca447d80b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Stokes", " ", "drift"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"v2rStokesDrift", "[", 
      RowBox[{"r_", ",", "z_"}], "]"}], ":=", 
     RowBox[{
      FractionBox["2", "omega"], "*", 
      RowBox[{"Re", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], "*", "qf", "*", 
            RowBox[{"F2", "[", "r", "]"}]}], "+", 
           RowBox[{"k", "*", 
            RowBox[{"G1", "[", "r", "]"}]}]}], ")"}], "*", 
         RowBox[{"Conjugate", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"qf", "^", "2"}]}], "*", 
            RowBox[{"F1", "[", "r", "]"}]}], "+", 
           RowBox[{
            FractionBox["1", "r"], "*", "qf", "*", 
            RowBox[{"F2", "[", "r", "]"}]}], "+", 
           RowBox[{
            FractionBox["1", "r"], "*", "\[ImaginaryI]", "*", "k", "*", 
            RowBox[{"G1", "[", "r", "]"}]}], "-", 
           RowBox[{"\[ImaginaryI]", "*", "k", "*", "qv", "*", 
            RowBox[{"G2", "[", "r", "]"}]}]}], "]"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"Cos", "[", 
              RowBox[{"kR", "*", "z"}], "]"}], ")"}], "^", "2"}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"Sin", "[", 
              RowBox[{"\[ImaginaryI]", "*", "kI", "*", "z"}], "]"}], ")"}], 
            "^", "2"}]}], ")"}]}], "+", 
        RowBox[{"\[ImaginaryI]", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "k"}], "*", 
            RowBox[{"F1", "[", "r", "]"}]}], "+", 
           RowBox[{"\[ImaginaryI]", "*", "qv", "*", 
            RowBox[{"G2", "[", "r", "]"}]}]}], ")"}], "*", 
         RowBox[{"Conjugate", "[", 
          RowBox[{
           RowBox[{"k", "*", "qf", "*", 
            RowBox[{"F2", "[", "r", "]"}]}], "+", 
           RowBox[{"\[ImaginaryI]", "*", 
            RowBox[{"k", "^", "2"}], "*", 
            RowBox[{"G1", "[", "r", "]"}]}]}], "]"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"Sin", "[", 
              RowBox[{"kR", "*", "z"}], "]"}], ")"}], "^", "2"}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"Sin", "[", 
              RowBox[{"\[ImaginaryI]", "*", "kI", "*", "z"}], "]"}], ")"}], 
            "^", "2"}]}], ")"}]}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
     RowBox[{"v2zStokesDrift", "[", 
      RowBox[{"r_", ",", "z_"}], "]"}], ":=", 
     RowBox[{
      FractionBox["2", "omega"], "*", 
      RowBox[{"Re", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], "*", "qf", "*", 
            RowBox[{"F2", "[", "r", "]"}]}], "+", 
           RowBox[{"k", "*", 
            RowBox[{"G1", "[", "r", "]"}]}]}], ")"}], "*", 
         RowBox[{"Conjugate", "[", 
          RowBox[{
           RowBox[{"k", "*", "qf", "*", 
            RowBox[{"F2", "[", "r", "]"}]}], "-", 
           RowBox[{"\[ImaginaryI]", "*", 
            RowBox[{"qv", "^", "2"}], "*", 
            RowBox[{"G1", "[", "r", "]"}]}]}], "]"}], "*", 
         FractionBox["1", "2"], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"2", "*", "kR", "*", "z"}], "]"}], "-", 
           RowBox[{"\[ImaginaryI]", "*", 
            RowBox[{"Sinh", "[", 
             RowBox[{"2", "*", "kI", "*", "z"}], "]"}]}]}], ")"}]}], "+", 
        RowBox[{"\[ImaginaryI]", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "k"}], "*", 
            RowBox[{"F1", "[", "r", "]"}]}], "+", 
           RowBox[{"\[ImaginaryI]", "*", "qv", "*", 
            RowBox[{"G2", "[", "r", "]"}]}]}], ")"}], "*", 
         RowBox[{"Conjugate", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"k", "^", "2"}]}], "*", 
            RowBox[{"F1", "[", "r", "]"}]}], "+", 
           RowBox[{"\[ImaginaryI]", "*", "k", "*", "qv", "*", 
            RowBox[{"G2", "[", "r", "]"}]}]}], "]"}], "*", 
         FractionBox["1", "2"], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"2", "*", "kR", "*", "z"}], "]"}], "+", 
           RowBox[{"\[ImaginaryI]", "*", 
            RowBox[{"Sinh", "[", 
             RowBox[{"2", "*", "kI", "*", "z"}], "]"}]}]}], ")"}]}]}], 
       "]"}]}]}], ";"}]}]}]], "Input",
 CellLabel->"In[77]:=",ExpressionUUID->"66c5e380-18bd-48e5-92d7-ae0ebbb0bd50"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Lagrangian", " ", "velocity"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"v2rLagrange", "[", 
      RowBox[{"r_", ",", "z_"}], "]"}], "=", 
     RowBox[{
      RowBox[{"v2r", "[", 
       RowBox[{"r", ",", "z"}], "]"}], "+", 
      RowBox[{"v2rStokesDrift", "[", 
       RowBox[{"r", ",", "z"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"v2zLagrange", "[", 
      RowBox[{"r_", ",", "z_"}], "]"}], "=", 
     RowBox[{
      RowBox[{"v2z", "[", 
       RowBox[{"r", ",", "z"}], "]"}], "+", 
      RowBox[{"v2zStokesDrift", "[", 
       RowBox[{"r", ",", "z"}], "]"}]}]}], ";"}]}]}]], "Input",
 CellLabel->
  "In[79]:=",ExpressionUUID->"fbc991da-7f53-4133-8474-e9ee5976e9d7"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Average mass transport velocity field", \
"Section",ExpressionUUID->"edfb3c68-2786-4ca4-9ef2-9235806ebab8"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"rMassCorrection", "[", 
    RowBox[{"r_", ",", "z_"}], "]"}], ":=", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", "*", "rhof", "*", 
      RowBox[{"cf", "^", "2"}]}]], 
    RowBox[{"Re", "[", 
     RowBox[{"pA", "*", 
      RowBox[{"J0", "[", 
       RowBox[{"qf", "*", "r"}], "]"}], "*", 
      RowBox[{"Cos", "[", 
       RowBox[{"k", "*", "z"}], "]"}], "*", 
      RowBox[{"Conjugate", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "qf"}], "*", "A1", "*", 
           RowBox[{"J1", "[", 
            RowBox[{"qf", "*", "r"}], "]"}]}], "-", 
          RowBox[{"\[ImaginaryI]", "*", "k", "*", "B1", "*", 
           RowBox[{"J1", "[", 
            RowBox[{"qv", "*", "r"}], "]"}]}]}], ")"}], "*", "2", "*", 
        RowBox[{"Cos", "[", 
         RowBox[{"k", "*", "z"}], "]"}]}], "]"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"zMassCorrection", "[", 
    RowBox[{"r_", ",", "z_"}], "]"}], ":=", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", "*", "rhof", "*", 
      RowBox[{"cf", "^", "2"}]}]], 
    RowBox[{"Re", "[", 
     RowBox[{"pA", "*", 
      RowBox[{"J0", "[", 
       RowBox[{"qf", "*", "r"}], "]"}], "*", 
      RowBox[{"Cos", "[", 
       RowBox[{"k", "*", "z"}], "]"}], "*", 
      RowBox[{"Conjugate", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", "*", "k", "*", "A1", "*", 
           RowBox[{"J0", "[", 
            RowBox[{"qf", "*", "r"}], "]"}]}], "+", 
          RowBox[{"qv", "*", "B1", "*", 
           RowBox[{"J0", "[", 
            RowBox[{"qv", "*", "r"}], "]"}]}]}], ")"}], "*", "2", "*", 
        "\[ImaginaryI]", "*", 
        RowBox[{"Sin", "[", 
         RowBox[{"k", "*", "z"}], "]"}]}], "]"}]}], "]"}]}]}], 
  ";"}]}], "Input",
 CellLabel->"In[81]:=",ExpressionUUID->"e936799a-4f70-4f96-aea8-0fe093d30eb7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"average", " ", "mass", " ", "transport", " ", "velocity"}], 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"v2rM", "[", 
      RowBox[{"r_", ",", "z_"}], "]"}], "=", 
     RowBox[{
      RowBox[{"v2r", "[", 
       RowBox[{"r", ",", "z"}], "]"}], "+", 
      RowBox[{"rMassCorrection", "[", 
       RowBox[{"r", ",", "z"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"v2zM", "[", 
      RowBox[{"r_", ",", "z_"}], "]"}], "=", 
     RowBox[{
      RowBox[{"v2z", "[", 
       RowBox[{"r", ",", "z"}], "]"}], "+", 
      RowBox[{"zMassCorrection", "[", 
       RowBox[{"r", ",", "z"}], "]"}]}]}], ";"}]}]}]], "Input",
 CellLabel->
  "In[83]:=",ExpressionUUID->"47e117ab-8ca8-481e-94a3-248635053735"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solution by Schuster & Matz (1940)", \
"Section",ExpressionUUID->"a2f4e280-439a-42ba-be14-299d8b6fe47b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"v2rSchusterMatz", "[", 
    RowBox[{"r_", ",", "z_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["3", "8"]}], "*", 
    FractionBox[
     RowBox[{
      RowBox[{"pA", "^", "2"}], "*", "omega"}], 
     RowBox[{
      RowBox[{"cf", "^", "4"}], "*", 
      RowBox[{"rhof", "^", "2"}]}]], "*", "r", "*", 
    RowBox[{"Cos", "[", 
     RowBox[{"2", "*", 
      RowBox[{"Re", "[", "kf", "]"}], "*", 
      RowBox[{"(", 
       RowBox[{"z", "-", 
        FractionBox["\[Lambda]", "4"]}], ")"}]}], "]"}], "*", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"r", "^", "2"}], 
       RowBox[{"a", "^", "2"}]]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"v2zSchusterMatz", "[", 
    RowBox[{"r_", ",", "z_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["3", "8"]}], "*", 
    FractionBox[
     RowBox[{"pA", "^", "2"}], 
     RowBox[{
      RowBox[{"cf", "^", "3"}], "*", 
      RowBox[{"rhof", "^", "2"}]}]], "*", 
    RowBox[{"Sin", "[", 
     RowBox[{"2", "*", 
      RowBox[{"Re", "[", "kf", "]"}], "*", 
      RowBox[{"(", 
       RowBox[{"z", "-", 
        FractionBox["\[Lambda]", "4"]}], ")"}]}], "]"}], "*", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"2", "*", 
        RowBox[{"r", "^", "2"}]}], 
       RowBox[{"a", "^", "2"}]]}], ")"}]}]}], 
  ";"}]}], "Input",ExpressionUUID->"f0761a98-c5cc-4ddf-a922-5effd45f220f"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Analysis of velocity profiles", \
"Section",ExpressionUUID->"200aeaaa-0a2a-43de-a47a-3f1f1c4b0120"],

Cell["\<\
To activate the analysis of velocity profiles, uncomment (i.e. remove \
\[OpenCurlyDoubleQuote] (* \[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote] *) \[OpenCurlyDoubleQuote]) the corresponding line.\
\>", "Text",ExpressionUUID->"cbb994c6-d51d-4334-bdf6-c0736c7abf15"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"v2z", "[", 
       RowBox[{"rTest4", ",", 
        FractionBox["\[Lambda]R", "8"]}], "]"}], ",", 
      RowBox[{"v2zLagrange", "[", 
       RowBox[{"rTest4", ",", 
        FractionBox["\[Lambda]R", "8"]}], "]"}], ",", 
      RowBox[{"v2zM", "[", 
       RowBox[{"rTest4", ",", 
        FractionBox["\[Lambda]R", "8"]}], "]"}], ",", 
      RowBox[{"v2zSchusterMatz", "[", 
       RowBox[{"rTest4", ",", 
        FractionBox["\[Lambda]", "8"]}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"rTest4", ",", 
      RowBox[{"a", "/", "2000"}], ",", "a"}], "}"}], ",", 
    RowBox[{
    "PlotLabel", "\[Rule]", "\"\<Velocity profile at z = \[Lambda]/8\>\""}], 
    ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"r", ",", "Velocity"}], "}"}]}], ",", 
    RowBox[{"PlotLegends", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\!\(\*SuperscriptBox[SubscriptBox[\(v\), \(2 z\)], \(E\)]\)\>\"", 
       ",", "\"\<\!\(\*SuperscriptBox[SubscriptBox[\(v\), \(2 z\)], \
\(L\)]\)\>\"", ",", 
       "\"\<\!\(\*SuperscriptBox[SubscriptBox[\(v\), \(2 z\)], \(M\)]\)\>\"", 
       ",", "\"\<\!\(\*SuperscriptBox[SubscriptBox[\(v\), \(2 z\)], \
\(S\)]\)\>\""}], "}"}]}]}], "]"}], " ", 
  "*)"}]], "Input",ExpressionUUID->"0ab835ef-c099-4a91-be19-4f61096f49ce"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Analysis of streaming fields", \
"Section",ExpressionUUID->"152f6ad0-5b29-4dc1-8d4e-d8a659fcd3a4"],

Cell["\<\
To activate the analysis of streaming fields, uncomment (i.e.remove \" (* \" \
and \" *) \") the corresponding lines. Note that it might take a lot of time \
for Mathematica to evaluate and display the streaming fields.\
\>", "Text",ExpressionUUID->"adfadea1-ff35-457e-9646-5e44edce012b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "helper", " ", "functions", " ", "that", " ", "are", " ", "needed", " ", 
    "due", " ", "to", " ", "the", " ", "usually", " ", "large", " ", 
    "difference", " ", "in", " ", "the", " ", "plotted", " ", "r", " ", "and",
     " ", "z", " ", "range"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Options", "[", "modifiedStreamPlot", "]"}], "=", 
     RowBox[{"Options", "[", "StreamPlot", "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"modifiedStreamPlot", "[", 
     RowBox[{"function_", ",", 
      RowBox[{"{", 
       RowBox[{"r_", ",", "r0_", ",", "r1_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"z_", ",", "z0_", ",", "z1_"}], "}"}], ",", 
      RowBox[{"opts", ":", 
       RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"u", ",", "v", ",", 
        RowBox[{"a", "=", 
         RowBox[{"OptionValue", "[", "AspectRatio", "]"}]}]}], "}"}], ",", 
      RowBox[{"Show", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"StreamPlot", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"1", "/", 
               RowBox[{"(", 
                RowBox[{"r1", "-", "r0"}], ")"}]}], ",", 
              RowBox[{"a", "/", 
               RowBox[{"(", 
                RowBox[{"z1", "-", "z0"}], ")"}]}]}], "}"}], " ", 
            RowBox[{"(", 
             RowBox[{"function", "/.", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"r", "\[Rule]", 
                 RowBox[{"r0", "+", 
                  RowBox[{"u", " ", 
                   RowBox[{"(", 
                    RowBox[{"r1", "-", "r0"}], ")"}]}]}]}], ",", 
                RowBox[{"z", "\[Rule]", 
                 RowBox[{"z0", "+", 
                  RowBox[{
                   RowBox[{"v", "/", "a"}], " ", 
                   RowBox[{"(", 
                    RowBox[{"z1", "-", "z0"}], ")"}]}]}]}]}], "}"}]}], 
             ")"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"u", ",", "0", ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"v", ",", "0", ",", "a"}], "}"}], ",", "opts"}], "]"}], "/.", 
         RowBox[{
          RowBox[{"Arrow", "[", "pts_", "]"}], "\[RuleDelayed]", 
          RowBox[{"Arrow", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"r0", ",", "z0"}], "}"}], "+", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"r1", "-", "r0"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"z1", "-", "z0"}], ")"}], "/", "a"}]}], "}"}], 
                " ", "#"}]}], ")"}], "&"}], "/@", "pts"}], "]"}]}]}], ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"r0", ",", "r1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"z0", ",", "z1"}], "}"}]}], "}"}]}]}], "]"}]}], 
     "]"}]}]}]}]], "Input",
 CellLabel->"In[88]:=",ExpressionUUID->"1f5dc122-faf8-43a5-82fe-57d390cf1e5e"],

Cell[CellGroupData[{

Cell["Eulerian streaming velocity field", \
"Subsection",ExpressionUUID->"ca7c0cfc-1d78-4a49-9c20-29ba677c7478"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"modifiedStreamPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"v2r", "[", 
       RowBox[{"rTest3", ",", "zTest3"}], "]"}], ",", 
      RowBox[{"v2z", "[", 
       RowBox[{"rTest3", ",", "zTest3"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"rTest3", ",", 
      RowBox[{"a", "/", "1000"}], ",", "a"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"zTest3", ",", "0", ",", "\[Lambda]"}], "}"}], ",", 
    RowBox[{"StreamPoints", "\[Rule]", "Fine"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"r", ",", "z"}], "}"}]}], ",", 
    RowBox[{"PerformanceGoal", "->", "\"\<Speed\>\""}]}], "]"}], " ", 
  "*)"}]], "Input",ExpressionUUID->"8ded9294-df4c-45c9-9c64-660c2bea6b06"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Lagrangian streaming velocity field", \
"Subsection",ExpressionUUID->"5d77882a-24c3-40ea-bb4d-d8fd3ba71230"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"modifiedStreamPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"v2rLagrange", "[", 
       RowBox[{"rTest3", ",", "zTest3"}], "]"}], ",", 
      RowBox[{"v2zLagrange", "[", 
       RowBox[{"rTest3", ",", "zTest3"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"rTest3", ",", 
      RowBox[{"a", "/", "1000"}], ",", "a"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"zTest3", ",", "0", ",", "\[Lambda]"}], "}"}], ",", 
    RowBox[{"StreamPoints", "\[Rule]", "Fine"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"r", ",", "z"}], "}"}]}], ",", 
    RowBox[{"PerformanceGoal", "->", "\"\<Speed\>\""}]}], "]"}], " ", 
  "*)"}]], "Input",ExpressionUUID->"3b5d3f2a-f74e-4dec-a2f1-41868aa88504"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Average mass transport velocity field", \
"Subsection",ExpressionUUID->"4a7f3bfe-1e59-478b-8f41-a5b5c8937eda"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"modifiedStreamPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"v2rM", "[", 
       RowBox[{"rTest3", ",", "zTest3"}], "]"}], ",", 
      RowBox[{"v2zM", "[", 
       RowBox[{"rTest3", ",", "zTest3"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"rTest3", ",", 
      RowBox[{"a", "/", "1000"}], ",", "a"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"zTest3", ",", "0", ",", "\[Lambda]"}], "}"}], ",", 
    RowBox[{"StreamPoints", "\[Rule]", "Fine"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"r", ",", "z"}], "}"}]}], ",", 
    RowBox[{"PerformanceGoal", "->", "\"\<Speed\>\""}]}], "]"}], " ", 
  "*)"}]], "Input",ExpressionUUID->"e338ca04-2148-420c-a930-a6870e20c96a"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Streaming velocity field by Schuster & Matz (1940)", \
"Subsection",ExpressionUUID->"388d99cf-0840-49fd-b53b-23cc335f203e"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"modifiedStreamPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"v2rSchusterMatz", "[", 
       RowBox[{"rTest3", ",", "zTest3"}], "]"}], ",", 
      RowBox[{"v2zSchusterMatz", "[", 
       RowBox[{"rTest3", ",", "zTest3"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"rTest3", ",", 
      RowBox[{"a", "/", "1000"}], ",", "a"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"zTest3", ",", "0", ",", "\[Lambda]"}], "}"}], ",", 
    RowBox[{"StreamPoints", "\[Rule]", "Fine"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"r", ",", "z"}], "}"}]}], ",", 
    RowBox[{"PerformanceGoal", "->", "\"\<Speed\>\""}]}], "]"}], " ", 
  "*)"}]], "Input",ExpressionUUID->"68a34f38-17dd-4f41-b175-f14a2c71cd6c"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{Full, Full},
WindowMargins->{{-8, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{32000, 32000},
PrintingOptions->{"Magnification"->1.,
"PaperOrientation"->"Portrait",
"PaperSize"->{594.9599999999999, 842.04}},
PrivateNotebookOptions->{"FileOutlineCache"->False},
TrackCellChangeTimes->False,
Magnification:>1.1 Inherited,
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]

